@@ -4,34 +4,42 @@ package Array::Iterator::Reusable;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.07'; # VERSION
 
 use Array::Iterator;
 our @ISA = qw(Array::Iterator);
 
 sub reset {
     my ($self) = @_;
+    $self->_iterated = 0;
     $self->_current_index = 0;
 }
 
 1;
-__END__
+#ABSTRACT: A subclass of Array::Iterator to allow reuse of iterators
+
+
+=pod
 
 =head1 NAME
 
 Array::Iterator::Reusable - A subclass of Array::Iterator to allow reuse of iterators
 
+=head1 VERSION
+
+version 0.07
+
 =head1 SYNOPSIS
 
   use Array::Iterator::Reusable;
-  
+
   # create an iterator with an array
   my $i = Array::Iterator::Reusable->new(1 .. 100);
-  
+
   # do something with the iterator
   my @accumulation;
-  push @accumulation => { item => $iterator->next() } while $iterator->hasNext();
-  
+  push @accumulation => { item => $iterator->next() } while $iterator->has_next();
+
   # now reset the iterator so we can do it again
   $iterator->reset();
 
@@ -47,13 +55,13 @@ This is a subclass of Array::Iterator, only those methods that have been added a
 
 =item B<reset>
 
-This resets the interal counter of the iterator back to the start of the array. 
+This resets the interal counter of the iterator back to the start of the array.
 
 =back
 
 =head1 BUGS
 
-None that I am aware of, if you find a bug, let me know, and I will be sure to fix it. 
+None that I am aware of, if you find a bug, let me know, and I will be sure to fix it.
 
 =head1 CODE COVERAGE
 
@@ -63,17 +71,32 @@ See the B<CODE COVERAGE> section of the B<Array::Iterator> documentation for inf
 
 This is a subclass of B<Array::Iterator>, please refer to it for more documenation.
 
-=head1 AUTHOR
+=head1 ORIGINAL AUTHOR
 
 stevan little, E<lt>stevan@iinteractive.comE<gt>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 ORIGINAL COPYRIGHT AND LICENSE
 
 Copyright 2004 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
+
+=head1 AUTHOR
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Steven Haryanto.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
